Changelog — ms3 0.1.2.post0.dev2+g9d887e1.dirty documentation

# Changelog

## Version 0.2.0

- extraction of metadata from scores

- conversion of MuseScore’s encoding of absolute chords

## Version 0.1.3

At this stage, the library can parse MuseScore 3 files to different types of lists:

- measures

- chords (= groups of notes) * including slurs and spanners such as pedal, 8va or hairpin markings * including lyrics

- notes

- harmonies

and also some basic metadata.

## Version 0.1.0

- Basic parser implemented

- Logging

- Measure lists